Learn R Programming

basket (version 0.9.2)

plot_map: Plot the Map Exchangeability of a Basket Trial

Description

The Maximum A Posteriori Probability (MAP) of an MEM is the estimate of the exchangeability structure of a basket trial. This function visualizes this matrix as an exchangeogram.

Usage

plot_map(x, ...)

Arguments

x

the exchangeability model.

...

other options passed to ggplot2 to alter the visual

Details

The `plot_pep` attempts to place the basket names to the left of the main diagonal in a way that makes it easy to read. However, for especially long basket names options are provided to ``fine tune'' the visualizations. These auxiliary options include:

  • [low] The color corresponding to a low degree of exchangeability. (Default "black")

  • [high] The color corresponding to a high degree of exchangeability. (Default "red")

  • [mid] The color corresponding to 50% exchangeability. (Default "orange")

  • [expand] The proportion to expand the viewport (Default expand = c(0.3, 0.3))

  • [text_size] The text size. (Default 4)

  • [legend_position] The legend position. (Default legend_position = c(0.25, 0.8)

  • [draw_legend] Should the legend be drawn? (Default TRUE)

  • [basket_name_hoffset] The horizontal offset of the basket names.. (Default 0)

  • [basket_name_hjust] The basket name justification.. (Default 1 - right justified)

Examples

Run this code
# NOT RUN {
# Create an MEM analysis of the Vemurafenib trial data.
data(vemu_wide)

mem_analysis <- mem_exact(vemu_wide$responders,
                          vemu_wide$evaluable,
                          vemu_wide$baskets)

plot_map(mem_analysis)
# }

Run the code above in your browser using DataLab