Learn R Programming

basket (version 0.10.11)

update_p0: Update Full Bayes results with different p0 values

Description

After running either `mem_mcmc` or `mem_exact`, the test can be updated without rerunning the entire analysis. This function provides updating of both the null response rate along with the alternative rerunning relevant test.

Usage

update_p0(res, p0 = 0.15, alternative = "greater")

Arguments

res

the result of an mem analysis.

p0

the null response rate for the poster probability calculation (default 0.15).

alternative

the alternative case definition (default greater)

Examples

Run this code
# NOT RUN {
# Create an MEM analysis of the Vemurafenib trial data.
data(vemu_wide)

mem_analysis <- mem_exact(
  vemu_wide$responders,
  vemu_wide$evaluable,
  vemu_wide$baskets
)

# Update the null from p0 = 0.15 the default, to p = 0.25.
update_p0(mem_analysis, 0.20)
# }

Run the code above in your browser using DataLab